import usb.backend
from usb.core import find
import usb.util


class _DeviceDescriptor(object):
    def __init__(self, idVendor, idProduct,iSerialNumber):
        self.bLength = 18
        self.bDescriptorType = usb.util.DESC_TYPE_DEVICE
        self.bcdUSB = 0x0200
        self.idVendor = idVendor
        self.idProduct = idProduct
        self.bcdDevice = 0x0001
        self.iManufacturer = 0
        self.iProduct = 0
        self.iSerialNumber = iSerialNumber
        self.bNumConfigurations = 0
        self.bMaxPacketSize0 = 64
        self.bDeviceClass = 0xff
        self.bDeviceSubClass = 0xff
        self.bDeviceProtocol = 0xff
        self.bus = 1
        self.address = 1
        self.port_number = None
        self.port_numbers = None
        self.speed = None

# We are only interested in test usb.find() function, we don't need
# to implement all IBackend stuff
class _MyBackend(usb.backend.IBackend):
    def __init__(self):
        self.devices = [_DeviceDescriptor(123,321,456),
                        _DeviceDescriptor(123,321,5678)]
    def enumerate_devices(self):
        return range(len(self.devices))
    def get_device_descriptor(self, dev):
        return self.devices[dev]

def test_find():
    b = _MyBackend()

    #First find a single device
    dev = find(backend=b, idVendor=123,idProduct=321)
    assert dev.idProduct!=None, "Failed to find the dummy device"

    #Try to find all the devices by their serial_number
    count=0
    serialNo = [456,5687]
    devices = find(find_all=True, backend=b, idVendor=123,idProduct=321)
    for i,dev in enumerate(devices):
    	count+=1

    #Check the number of devices we found is correct
    assert count==2,"Found the incorrect number of devices"